@@ -15,6 +15,7 @@ MIT License. (http://www.opensource.org/licenses/mit-license.php)
 
 """
 from __future__ import absolute_import
+import errno
 import os
 
 try:
@@ -27,7 +28,7 @@ from werkzeug.exceptions import RequestEntityTooLarge, UnsupportedMediaType
 
 from . import utils
 
-__version__ = '0.7'
+__version__ = '0.8.0'
 
 
 IMAGES = ('.jpg', '.jpeg', '.png', '.gif', '.bmp')
@@ -59,18 +60,15 @@ class FileStorage(object):
 
         base_path
         :   Absolute path where the files will be stored. Example:
-            `/var/www/static/media`.
+            `/var/www/example.com/media`.
 
-                UPLOAD_ROOT = os.path.abspath(os.path.normpath(
-                    os.path.join(
-                            os.path.dirname(__file__), '..',
-                                'static', 'media')
-                    )
-                )
+            MEDIA_DIR = realpath(join(BASE_DIR, 'media'))
 
         base_url
         :   The base path used when building the file's URL. By default
             is `/static/media`.
+            
+            MEDIA_URL = '/media'
 
         upload_to
         :   A pattern used to build the upload path on the fly. 
@@ -136,6 +134,11 @@ class FileStorage(object):
         """
         self.base_path = base_path.rstrip('/')
         self.base_url = base_url.rstrip('/')
+        try:
+            os.makedirs(os.path.realpath(base_path))
+        except (OSError), e:
+            if e.errno != errno.EEXIST:
+                raise
 
         self.upload_to = upload_to
         self.secret = secret
@@ -365,6 +368,8 @@ if sqlalchemy_available:
         filedata_class = File
 
         def __init__(self, base_path, base_url, default=None, **kwargs):
+            """
+            """
             self.base_path = base_path
             self.base_url = base_url
             self.default = default
